@@ -220,19 +220,19 @@ class S3Connection(FileSystem):
         from dslibrary.utils.file_utils import write_stream_with_read_on_close
         if "r" in mode:
             resp = self._client.get_object(Bucket=self._bucket, Key=path)
+            stream = resp["Body"]
+            # make 'stream' more file-like
+            stream.readable = lambda: True
+            stream.writable = lambda: False
+            stream.seekable = lambda: False
+            if not hasattr(stream, "closed"):
+                stream.closed = False
+            stream.flush = lambda: None
+            stream.__enter__ = lambda *a, **k: stream
+            stream.__exit__ = lambda *a, **k: stream.close()
             if mode == "r":
-                rdr = resp["Body"]
-                # TODO inelegant hack to get a unicode stream
-                rdr.readable = lambda: True
-                rdr.writable = lambda: False
-                rdr.seekable = lambda: False
-                rdr.closed = False
-                rdr.flush = lambda: None
-                # TODO and to support 'with'
-                rdr.__enter__ = lambda *a, **k: rdr
-                rdr.__exit__ = lambda *a, **k: rdr.close()
-                return TextIOWrapper(rdr, 'utf-8')
-            return resp["Body"]
+                return TextIOWrapper(stream, 'utf-8')
+            return stream
         if self._read_only:
             raise PermissionError("this data source is read-only")
         if "w" in mode:
