@@ -38,6 +38,11 @@ class DSLibraryLocal(DSLibrary):
         :param kwargs:  Additional arguments to customize details of the operation.
         :return:    File-like object.
         """
+        # TODO  this is a workaround for a bug in "adlfs".  fsspec.open("abfs://...", ...) does not work: it eventually gets a stack overflow
+        if path.startswith("abfs://"):
+            fs = self.get_filesystem_connection(path, for_write="r" not in mode, **kwargs)
+            path_only = path.split("://")[1].split("/", maxsplit=1)[1]
+            return fs.open(path_only, mode=mode)
         return FileOpener(self._root).open(path, mode, **kwargs)
 
     def open_run_data(self, filename: str, mode: str = 'r'):
